Crate mpv_client_cross

Crate mpv_client_cross 

Re-exports

pub use node::Node;

Modules

node

Macros

osd
osd_async

Structs

Client
A type representing an owned client context.
ClientMessage
Data associated with Event::ClientMessage.
EndFile
Data associated with Event::EndFile.
Error
Handle
Representation of a borrowed client context used by the client API. Every client has its own private handle.
Hook
Data associated with Event::Hook.
LogMessage
Data associated with Event::LogMessage.
Property
Data associated with Event::GetPropertyReply and Event::PropertyChange.
StartFile
Data associated with Event::StartFile.
mpv_handle

Enums

Event
An enum representing the available events that can be received by Handle::wait_event.

Traits

Format

Type Aliases

Result